@@ -1,19 +1,21 @@
 package Pcore::App::API;
 
-use Pcore -role, -const, -export => { CONST => [qw[$TOKEN_TYPE $TOKEN_TYPE_USER_PASSWORD $TOKEN_TYPE_USER_TOKEN $TOKEN_TYPE_USER_SESSION]] };
+use Pcore -role, -const, -export;
 use Pcore::App::API::Map;
-use Pcore::App::API::Auth;
 use Pcore::Util::Data qw[from_b64 from_b64_url];
 use Pcore::Util::Digest qw[sha3_512];
 use Pcore::Util::Text qw[encode_utf8];
 use Pcore::Util::UUID qw[uuid_from_bin];
+use Pcore::App::API::Auth;
 
-has app => ( is => 'ro', isa => ConsumerOf ['Pcore::App'], required => 1 );
+our $EXPORT = { CONST => [qw[$TOKEN_TYPE $TOKEN_TYPE_USER_PASSWORD $TOKEN_TYPE_USER_TOKEN $TOKEN_TYPE_USER_SESSION]] };
 
-has map => ( is => 'ro', isa => InstanceOf ['Pcore::App::API::Map'], init_arg => undef );
+has app => ( required => 1, isa => ConsumerOf ['Pcore::App'] );
 
-has _auth_cb_queue => ( is => 'ro', isa => HashRef, init_arg => undef );
-has _auth_cache    => ( is => 'ro', isa => HashRef, init_arg => undef );
+has map => ( isa => InstanceOf ['Pcore::App::API::Map'], init_arg => undef );
+
+has _auth_cb_queue => ( isa => HashRef, init_arg => undef );
+has _auth_cache    => ( isa => HashRef, init_arg => undef );
 
 const our $TOKEN_TYPE_USER_PASSWORD => 1;
 const our $TOKEN_TYPE_USER_TOKEN    => 3;
@@ -205,9 +207,9 @@ sub authenticate_private ( $self, $private_token, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 78                   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 80                   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 111                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 113                  | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
