@@ -11,20 +11,20 @@ use Pcore::HTTP::Server::Request;
 # - *:80
 # - 127.0.0.1:80
 
-has listen => ( is => 'ro', isa => Str, required => 1 );
-has app => ( is => 'ro', isa => CodeRef | InstanceOf ['Pcore::App::Router'], required => 1 );
+has listen => ();    # ( is => 'ro', isa => Str, required => 1 );
+has app    => ();    # ( is => 'ro', isa => CodeRef | InstanceOf ['Pcore::App::Router'], required => 1 );
 
-has backlog          => ( is => 'ro', isa => Maybe [PositiveOrZeroInt], default => 0 );
-has tcp_no_delay     => ( is => 'ro', isa => Bool,                      default => 1 );
-has tcp_so_keepalive => ( is => 'ro', isa => Bool,                      default => 1 );
+has backlog          => 0;    # ( is => 'ro', isa => Maybe [PositiveOrZeroInt], default => 0 );
+has tcp_no_delay     => 1;    # ( is => 'ro', isa => Bool,                      default => 1 );
+has tcp_so_keepalive => 1;    # ( is => 'ro', isa => Bool,                      default => 1 );
 
-has server_tokens         => ( is => 'ro', isa => Maybe [Str],       default => "Pcore-HTTP-Server/$Pcore::VERSION" );
-has keepalive_timeout     => ( is => 'ro', isa => PositiveOrZeroInt, default => 60 );                                    # 0 - disable keepalive
-has client_header_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 60 );                                    # 0 - do not use
-has client_body_timeout   => ( is => 'ro', isa => PositiveOrZeroInt, default => 60 );                                    # 0 - do not use
-has client_max_body_size  => ( is => 'ro', isa => PositiveOrZeroInt, default => 0 );                                     # 0 - do not check
+has server_tokens         => "Pcore-HTTP-Server/$Pcore::VERSION";    # ( is => 'ro', isa => Maybe [Str] );
+has keepalive_timeout     => 60;                                     # ( is => 'ro', isa => PositiveOrZeroInt, default => 60 ); # 0 - disable keepalive
+has client_header_timeout => 60;                                     # ( is => 'ro', isa => PositiveOrZeroInt, default => 60 ); # 0 - do not use
+has client_body_timeout   => 60;                                     # ( is => 'ro', isa => PositiveOrZeroInt, default => 60 ); # 0 - do not use
+has client_max_body_size  => 0;                                      # ( is => 'ro', isa => PositiveOrZeroInt, default => 0 );  # 0 - do not check
 
-has _listen_socket => ( is => 'ro', isa => Object, init_arg => undef );
+has _listen_socket => ();                                            # ( is => 'ro', isa => Object, init_arg => undef );
 
 const our $PSGI_ENV => {
     'psgi.version'      => [ 1, 1 ],
@@ -74,14 +74,14 @@ sub run ($self) {
 }
 
 sub _on_prepare ( $self, $fh, $host, $port ) {
-    return $self->backlog // 0;
+    return $self->{backlog} // 0;
 }
 
 sub _on_accept ( $self, $fh, $host, $port ) {
     Pcore::AE::Handle->new(
         fh              => $fh,
-        tcp_no_delay    => $self->tcp_no_delay,
-        tcp_so_kepalive => $self->tcp_so_keepalive,
+        tcp_no_delay    => $self->{tcp_no_delay},
+        tcp_so_kepalive => $self->{tcp_so_keepalive},
         on_connect      => sub ( $h, @ ) {
             $self->wait_headers($h);
 
